@@ -22,8 +22,6 @@ from .selection_manager import DrSelectionManager
 from .properties import DrPropertiesDialog
 from .utilities import InvalidFileFormatException
 
-from .gi_composites import GtkTemplate
-
 class DrMotionBehavior():
 	_LIMIT = 10
 
@@ -39,19 +37,18 @@ class NoPixbufNoChangeException(Exception):
 
 ################################################################################
 
-@GtkTemplate(ui='/com/github/maoschanz/drawing/ui/image.ui')
+@Gtk.Template(resource_path='/com/github/maoschanz/drawing/ui/image.ui')
 class DrImage(Gtk.Box):
 	__gtype_name__ = 'DrImage'
 
-	_drawing_area = GtkTemplate.Child()
-	_h_scrollbar = GtkTemplate.Child()
-	_v_scrollbar = GtkTemplate.Child()
+	_drawing_area = Gtk.Template.Child()
+	_h_scrollbar = Gtk.Template.Child()
+	_v_scrollbar = Gtk.Template.Child()
 
 	SCALE_FACTOR = 1.0 # XXX doesn't work well enough to be anything else
 
 	def __init__(self, window, **kwargs):
 		super().__init__(**kwargs)
-		self.init_template()
 		self.window = window
 
 		self.gfile = None
@@ -60,11 +57,11 @@ class DrImage(Gtk.Box):
 		self._init_drawing_area()
 
 		self._update_background_color()
-		self.window._settings.connect('changed::ui-background-rgba', \
+		self.window.gsettings.connect('changed::ui-background-rgba', \
 		                                          self._update_background_color)
 
 		self._update_zoom_behavior()
-		self.window._settings.connect('changed::ctrl-zoom', \
+		self.window.gsettings.connect('changed::ctrl-zoom', \
 		                                             self._update_zoom_behavior)
 
 	def _init_drawing_area(self):
@@ -96,14 +93,14 @@ class DrImage(Gtk.Box):
 		self._drawing_area.connect('leave-notify-event', self.on_leave_image)
 
 	def _update_background_color(self, *args):
-		rgba = self.window._settings.get_strv('ui-background-rgba')
+		rgba = self.window.gsettings.get_strv('ui-background-rgba')
 		self._bg_rgba = (float(rgba[0]), float(rgba[1]), \
 		                                         float(rgba[2]), float(rgba[3]))
 		# We remember this data here for performance: it's used by the `on_draw`
 		# method which is called a lot, and reading a gsettings costs a lot.
 
 	def _update_zoom_behavior(self, *args):
-		self._ctrl_to_zoom = self.window._settings.get_boolean('ctrl-zoom')
+		self._ctrl_to_zoom = self.window.gsettings.get_boolean('ctrl-zoom')
 
 	############################################################################
 	# Image initialization #####################################################
@@ -178,7 +175,7 @@ class DrImage(Gtk.Box):
 	def _load_pixbuf_common(self, pixbuf):
 		if not pixbuf.get_has_alpha():
 			pixbuf = pixbuf.add_alpha(False, 255, 255, 255)
-		background_rgba = self.window._settings.get_strv('default-rgba')
+		background_rgba = self.window.gsettings.get_strv('default-rgba')
 		self._history.set_initial_operation(background_rgba, pixbuf, \
 		                                pixbuf.get_width(), pixbuf.get_height())
 		self.set_main_pixbuf(pixbuf)
@@ -418,7 +415,7 @@ class DrImage(Gtk.Box):
 		the selected tool."""
 		if self.motion_behavior == DrMotionBehavior.SLIP:
 			if not self._is_slip_moving():
-				self.window.options_manager.on_middle_click()
+				self.window.on_middle_click()
 			self.motion_behavior = DrMotionBehavior.HOVER
 			return
 		self.motion_behavior = DrMotionBehavior.HOVER
@@ -575,6 +572,7 @@ class DrImage(Gtk.Box):
 		                                               apply_to_selection, True)
 		# FIXME using local deltas this way "works" but isn't mathematically
 		# correct: scaled selections have a "null" and excentred central nineth
+		# ^ c'est vrai ça ??
 		wl += 0.4 * width * self.zoom_level
 		wr -= 0.4 * width * self.zoom_level
 		ht += 0.4 * height * self.zoom_level
