@@ -79,24 +79,27 @@ class Application(Gtk.Application):
 		builder = Gtk.Builder.new_from_resource(APP_PATH + '/ui/app-menus.ui')
 		menubar_model = builder.get_object('menu-bar')
 		self.set_menubar(menubar_model)
-		if self.prefers_app_menu():
-			appmenu_model = builder.get_object('app-menu')
-			self.set_app_menu(appmenu_model)
 
 	def _build_actions(self):
-		"""Add app-wide actions."""
+		"""Add all app-wide actions."""
 		self.add_action_simple('new_window', self.on_new_window, ['<Ctrl>n'])
 		self.add_action_simple('settings', self.on_prefs, None)
 		if self.is_beta():
 			self.add_action_simple('report_bug', self.on_report, None)
 		self.add_action_simple('shortcuts', self.on_shortcuts, \
 		                                         ['<Ctrl>question', '<Ctrl>F1'])
+
 		self.add_action_simple('help', self.on_help_index, ['F1'])
 		self.add_action_simple('help_main', self.on_help_main, None)
+		self.add_action_simple('help_zoom', self.on_help_zoom, None)
+		self.add_action_simple('help_fullscreen', self.on_help_fullscreen, None)
 		self.add_action_simple('help_tools', self.on_help_tools, None)
+		self.add_action_simple('help_colors', self.on_help_colors, None)
 		self.add_action_simple('help_transform', self.on_help_transform, None)
 		self.add_action_simple('help_selection', self.on_help_selection, None)
 		self.add_action_simple('help_prefs', self.on_help_prefs, None)
+		self.add_action_simple('help_whats_new', self.on_help_whats_new, None)
+
 		self.add_action_simple('about', self.on_about, ['<Shift>F1'])
 		self.add_action_simple('quit', self.on_quit, ['<Ctrl>q'])
 
@@ -184,7 +187,7 @@ class Application(Gtk.Application):
 			# giving files without '-n' is equivalent to giving files with '-t'
 			for fpath in arguments:
 				f = self._get_valid_file(args[1], fpath)
-				# here f can be a GioFile or a boolea; True would mean the app
+				# here f can be a GioFile or a boolean: True would mean the app
 				# should open a new blank image.
 				if f != False:
 					f = None if f == True else f
@@ -232,30 +235,32 @@ class Application(Gtk.Application):
 		self._show_help_page('')
 
 	def on_help_main(self, *args):
-		"""Action callback, showing the 'basic features' page of the user help
-		manual."""
 		self._show_help_page('/main_features')
 
+	def on_help_zoom(self, *args):
+		self._show_help_page('/zoom_preview')
+
+	def on_help_fullscreen(self, *args):
+		self._show_help_page('/fullscreen')
+
 	def on_help_tools(self, *args):
-		"""Action callback, showing the 'classic tools' page of the user help
-		manual."""
 		self._show_help_page('/tools_classic')
 
+	def on_help_colors(self, *args):
+		self._show_help_page('/tools_classic_colors')
+
 	def on_help_transform(self, *args):
-		"""Action callback, showing the 'transform tools' page of the user help
-		manual."""
 		self._show_help_page('/tools_transform')
 
 	def on_help_selection(self, *args):
-		"""Action callback, showing the 'selection tools' page of the user help
-		manual."""
 		self._show_help_page('/tools_selection')
 
 	def on_help_prefs(self, *args):
-		"""Action callback, showing the 'preferences' page of the user help
-		manual."""
 		self._show_help_page('/preferences')
 
+	def on_help_whats_new(self, *args):
+		self._show_help_page('/whats_new')
+
 	def on_about(self, *args):
 		"""Action callback, showing the "about" dialog."""
 		about_dialog = Gtk.AboutDialog(transient_for=self.props.active_window,
@@ -276,6 +281,8 @@ class Application(Gtk.Application):
 		bug_report_btn = Gtk.LinkButton(halign=Gtk.Align.CENTER, visible=True, \
 		                    label=_("Report bugs or ideas"), uri=BUG_REPORT_URL)
 		# about_dialog.get_content_area().add(bug_report_btn) # should i?
+		about_dialog.set_icon_name('com.github.maoschanz.drawing')
+
 		about_dialog.run()
 		about_dialog.destroy()
 
@@ -312,6 +319,9 @@ class Application(Gtk.Application):
 		the headerbar."""
 		return (int(self._version.split('.')[1]) * 5) % 10 == 5
 
+	def get_current_version(self):
+		return self._version
+
 	def add_action_simple(self, action_name, callback, shortcuts):
 		action = Gio.SimpleAction.new(action_name, None)
 		action.connect('activate', callback)
