@@ -18,30 +18,27 @@
 from gi.repository import Gtk, Gio, Gdk
 from .utilities import utilities_add_unit_to_spinbtn
 
-from .gi_composites import GtkTemplate
-
-@GtkTemplate(ui='/com/github/maoschanz/drawing/ui/preferences.ui')
+@Gtk.Template(resource_path='/com/github/maoschanz/drawing/ui/preferences.ui')
 class DrPrefsWindow(Gtk.Window):
 	__gtype_name__ = 'DrPrefsWindow'
 
-	content_area = GtkTemplate.Child()
-	stack = GtkTemplate.Child()
+	content_area = Gtk.Template.Child()
+	stack = Gtk.Template.Child()
 
-	page_images = GtkTemplate.Child()
-	page_tools = GtkTemplate.Child()
-	page_advanced = GtkTemplate.Child()
+	page_images = Gtk.Template.Child()
+	page_tools = Gtk.Template.Child()
+	page_advanced = Gtk.Template.Child()
 
-	adj_width = GtkTemplate.Child()
-	adj_height = GtkTemplate.Child()
-	adj_preview = GtkTemplate.Child()
+	adj_width = Gtk.Template.Child()
+	adj_height = Gtk.Template.Child()
+	adj_preview = Gtk.Template.Child()
 
 	_current_grid = None
 	_grid_attach_cpt = 0
-	_settings = Gio.Settings.new('com.github.maoschanz.drawing')
+	_gsettings = Gio.Settings.new('com.github.maoschanz.drawing')
 
 	def __init__(self, is_beta, wants_csd, **kwargs):
 		super().__init__(**kwargs)
-		self.init_template()
 		if wants_csd:
 			header_bar = Gtk.HeaderBar(
 				visible=True, \
@@ -145,6 +142,7 @@ class DrPrefsWindow(Gtk.Window):
 		tools_dict = {
 			'eraser': _("Eraser"),
 			'highlight': _("Highlighter"),
+			'brush': _("Brush"),
 			'points': _("Points"),
 			'free_select': _("Free selection"),
 			'color_select': _("Color selection"),
@@ -164,7 +162,7 @@ class DrPrefsWindow(Gtk.Window):
 			# This label will not be displayed in the UI of stable versions
 			self.add_switch(_("Development features"), 'devel-only')
 		else:
-			self._settings.set_boolean('devel-only', False)
+			self._gsettings.set_boolean('devel-only', False)
 		self.add_colorbtn(_("Background color"), 'ui-background-rgba')
 
 		self.add_section_separator()
@@ -228,13 +226,13 @@ class DrPrefsWindow(Gtk.Window):
 
 	def add_switch(self, label_text, key):
 		switch = Gtk.Switch()
-		switch.set_active(self._settings.get_boolean(key))
+		switch.set_active(self._gsettings.get_boolean(key))
 		switch.connect('notify::active', self.on_bool_changed, key)
 		self.add_row(label_text, switch)
 
 	def add_colorbtn(self, label_text, key):
 		color_btn = Gtk.ColorButton(use_alpha=True)
-		background_rgba = self._settings.get_strv(key)
+		background_rgba = self._gsettings.get_strv(key)
 		r = float(background_rgba[0])
 		g = float(background_rgba[1])
 		b = float(background_rgba[2])
@@ -246,7 +244,7 @@ class DrPrefsWindow(Gtk.Window):
 
 	def add_adj(self, label_text, key, adj):
 		spinbtn = Gtk.SpinButton(adjustment=adj)
-		spinbtn.set_value(self._settings.get_int(key))
+		spinbtn.set_value(self._gsettings.get_int(key))
 		utilities_add_unit_to_spinbtn(spinbtn, 4, 'px')
 		spinbtn.connect('value-changed', self.on_adj_changed, key)
 		self.add_row(label_text, spinbtn)
@@ -263,7 +261,7 @@ class DrPrefsWindow(Gtk.Window):
 
 	def build_radio_btn(self, label, btn_id, key, group):
 		btn = Gtk.RadioButton(label=label, visible=True, group=group)
-		active_id = self._settings.get_string(key)
+		active_id = self._gsettings.get_string(key)
 		btn.set_active(btn_id == active_id)
 		btn.connect('toggled', self.on_radio_btn_changed, key, btn_id)
 		return btn
@@ -277,7 +275,7 @@ class DrPrefsWindow(Gtk.Window):
 
 	def build_check_btn(self, label, row_id, key):
 		btn = Gtk.CheckButton(label=label, visible=True)
-		array_of_strings = self._settings.get_strv(key)
+		array_of_strings = self._gsettings.get_strv(key)
 		btn.set_active(row_id not in array_of_strings)
 		btn.connect('toggled', self.on_check_btn_changed, key, row_id)
 		return btn
@@ -286,27 +284,27 @@ class DrPrefsWindow(Gtk.Window):
 	# Generic callbacks ########################################################
 
 	def on_bool_changed(self, switch, state, key):
-		self._settings.set_boolean(key, switch.get_active())
+		self._gsettings.set_boolean(key, switch.get_active())
 
 	def on_adj_changed(self, spinbtn, key):
-		self._settings.set_int(key, spinbtn.get_value_as_int())
+		self._gsettings.set_int(key, spinbtn.get_value_as_int())
 
 	def on_check_btn_changed(self, checkbtn, key, btn_id):
-		array_of_strings = self._settings.get_strv(key)
+		array_of_strings = self._gsettings.get_strv(key)
 		if checkbtn.get_active():
 			array_of_strings.remove(btn_id)
 		else:
 			array_of_strings.append(btn_id)
-		self._settings.set_strv(key, array_of_strings)
+		self._gsettings.set_strv(key, array_of_strings)
 
 	def on_radio_btn_changed(self, radiobtn, key, btn_id):
 		if self._radio_are_active:
-			self._settings.set_string(key, btn_id)
+			self._gsettings.set_string(key, btn_id)
 
 	def on_colorbtn_changed(self, color_btn, key):
 		c = color_btn.get_rgba()
 		color_array = [str(c.red), str(c.green), str(c.blue), str(c.alpha)]
-		self._settings.set_strv(key, color_array)
+		self._gsettings.set_strv(key, color_array)
 
 	############################################################################
 	# Low-level packing ########################################################
