@@ -19,10 +19,9 @@
 import os
 from gi.repository import Gtk, Gdk, Gio, GdkPixbuf, GLib
 
-from .gi_composites import GtkTemplate
-
 # Import tools
 from .tool_arc import ToolArc
+from .tool_brush import ToolBrush
 from .tool_eraser import ToolEraser
 from .tool_experiment import ToolExperiment
 from .tool_highlight import ToolHighlighter
@@ -77,38 +76,36 @@ DEFAULT_TOOL_ID = 'pencil'
 
 ################################################################################
 
-@GtkTemplate(ui=UI_PATH+'window.ui')
+@Gtk.Template(resource_path=UI_PATH+'window.ui')
 class DrWindow(Gtk.ApplicationWindow):
 	__gtype_name__ = 'DrWindow'
 
-	_settings = Gio.Settings.new('com.github.maoschanz.drawing')
+	gsettings = Gio.Settings.new('com.github.maoschanz.drawing')
 
 	# Window empty widgets
-	tools_flowbox = GtkTemplate.Child()
-	toolbar_box = GtkTemplate.Child()
-	info_bar = GtkTemplate.Child()
-	info_label = GtkTemplate.Child()
-	info_action = GtkTemplate.Child()
-	notebook = GtkTemplate.Child()
-	bottom_panes_box = GtkTemplate.Child()
-	tools_scrollable_box = GtkTemplate.Child()
-	tools_nonscrollable_box = GtkTemplate.Child()
-	fullscreen_btn = GtkTemplate.Child()
-	fullscreen_icon = GtkTemplate.Child()
+	tools_flowbox = Gtk.Template.Child()
+	toolbar_box = Gtk.Template.Child()
+	info_bar = Gtk.Template.Child()
+	info_label = Gtk.Template.Child()
+	info_action = Gtk.Template.Child()
+	notebook = Gtk.Template.Child()
+	bottom_panes_box = Gtk.Template.Child()
+	unfullscreen_btn = Gtk.Template.Child()
+	bottom_meta_box = Gtk.Template.Child()
+	tools_scrollable_box = Gtk.Template.Child()
+	tools_nonscrollable_box = Gtk.Template.Child()
 
 	def __init__(self, **kwargs):
 		super().__init__(**kwargs)
-		self.init_template()
 		self.app = kwargs['application']
 
-		self.fullscreened = False
 		self.pointer_to_current_page = None # this ridiculous hack allows to
 		                   # manage several tabs in a single window despite the
 		                                      # notebook widget being pure shit
 		self.active_tool_id = None
 		self._is_tools_initialisation_finished = False
 
-		if self._settings.get_boolean('maximized'):
+		if self.gsettings.get_boolean('maximized'):
 			self.maximize()
 		# self.resize(360, 648)
 		# self.resize(720, 288)
@@ -145,16 +142,42 @@ class DrWindow(Gtk.ApplicationWindow):
 
 		self._enable_first_tool()
 		self.set_picture_title()
+		self._try_show_release_notes()
+
+	def _try_show_release_notes(self):
+		last_version = self.gsettings.get_string('last-version')
+		current_version = self.app.get_current_version()
+		if current_version == last_version:
+			return
+
+		dialog = DrMessageDialog(self)
+		# Context: %s is the version number of the app
+		label = _("It's the first time you use Drawing %s, " + \
+		                                   "would you like to read what's new?")
+		dialog.add_string(label % current_version)
+
+		no_id = dialog.set_action(_("No"), None, False)
+		later_id = dialog.set_action(_("Later"), None, False)
+		yes_id = dialog.set_action(_("Yes"), 'suggested-action', True)
+		result = dialog.run()
+		dialog.destroy()
+
+		if result == later_id:
+			return
+		if result == yes_id:
+			self.app.on_help_whats_new()
+		self.gsettings.set_string('last-version', current_version)
 
 	def _init_tools(self):
 		"""Initialize all tools, building the UI for them including the menubar,
 		and enable the default tool."""
-		disabled_tools = self._settings.get_strv('disabled-tools')
-		dev = self._settings.get_boolean('devel-only')
+		disabled_tools = self.gsettings.get_strv('disabled-tools')
+		dev = self.gsettings.get_boolean('devel-only')
 		self.tools = {}
 		self.prompt_message(False, 'window has started, now loading tools')
 		# The order might be improvable
 		self._load_tool('pencil', ToolPencil, disabled_tools, dev)
+		self._load_tool('brush', ToolBrush, disabled_tools, dev)
 		self._load_tool('eraser', ToolEraser, disabled_tools, dev)
 		self._load_tool('highlight', ToolHighlighter, disabled_tools, dev)
 		self._load_tool('text', ToolText, disabled_tools, dev)
@@ -182,7 +205,7 @@ class DrWindow(Gtk.ApplicationWindow):
 			self.build_menubar_tools_menu()
 
 		# Initialisation of which tool is active
-		tool_id = self._settings.get_string('last-active-tool')
+		tool_id = self.gsettings.get_string('last-active-tool')
 		if tool_id not in self.tools:
 			tool_id = DEFAULT_TOOL_ID
 		self.active_tool_id = tool_id
@@ -254,9 +277,9 @@ class DrWindow(Gtk.ApplicationWindow):
 	def build_new_image(self, *args):
 		"""Open a new tab with a drawable blank image using the default values
 		defined by user's settings."""
-		width = self._settings.get_int('default-width')
-		height = self._settings.get_int('default-height')
-		rgba = self._settings.get_strv('default-rgba')
+		width = self.gsettings.get_int('default-width')
+		height = self.gsettings.get_int('default-height')
+		rgba = self.gsettings.get_strv('default-rgba')
 		self.build_new_tab(width=width, height=height, background_rgba=rgba)
 		self.set_picture_title()
 
@@ -313,7 +336,7 @@ class DrWindow(Gtk.ApplicationWindow):
 		self.set_picture_title(args[1].update_title())
 		self.minimap.set_zoom_label(args[1].zoom_level * 100)
 		args[1].update_history_sensitivity()
-		# On devrait être moins bourrin et conserver la sélection # TODO
+		# On devrait être moins bourrin et conserver la sélection # TODO ?
 
 	def update_tabs_menu_section(self, *args):
 		action = self.lookup_action('active_tab')
@@ -369,9 +392,9 @@ class DrWindow(Gtk.ApplicationWindow):
 			if not self.get_active_image().try_close_tab():
 				return True
 
-		self.options_manager.remember_options()
-		self._settings.set_string('last-active-tool', self.active_tool_id)
-		self._settings.set_boolean('maximized', self.is_maximized())
+		self.options_manager.persist_tools_options()
+		self.gsettings.set_string('last-active-tool', self.active_tool_id)
+		self.gsettings.set_boolean('maximized', self.is_maximized())
 		return False
 
 	############################################################################
@@ -389,12 +412,12 @@ class DrWindow(Gtk.ApplicationWindow):
 		self.connect('configure-event', self._adapt_to_window_size)
 
 		# When a setting changes
-		self._settings.connect('changed::show-labels', self.on_show_labels_setting_changed)
-		self._settings.connect('changed::deco-type', self.on_layout_changed)
-		self._settings.connect('changed::big-icons', self.on_icon_size_changed)
-		# self._settings.connect('changed::preview-size', self.show_info_settings)
-		# self._settings.connect('changed::devel-only', self.show_info_settings)
-		self._settings.connect('changed::disabled-tools', self.show_info_settings)
+		self.gsettings.connect('changed::show-labels', self.on_show_labels_setting_changed)
+		self.gsettings.connect('changed::deco-type', self.on_layout_changed)
+		self.gsettings.connect('changed::big-icons', self.on_icon_size_changed)
+		# self.gsettings.connect('changed::preview-size', self.show_info_settings)
+		# self.gsettings.connect('changed::devel-only', self.show_info_settings)
+		self.gsettings.connect('changed::disabled-tools', self.show_info_settings)
 		# Other settings are connected in DrImage
 
 		# What happens when the active image change
@@ -462,15 +485,20 @@ class DrWindow(Gtk.ApplicationWindow):
 		self.add_action_boolean('toggle_preview', False, self.action_toggle_preview)
 		self.app.set_accels_for_action('win.toggle_preview', ['<Ctrl>m'])
 
-		show_labels = self._settings.get_boolean('show-labels')
+		show_labels = self.gsettings.get_boolean('show-labels')
 		self.add_action_boolean('show_labels', show_labels, self.action_show_labels)
 		self.app.set_accels_for_action('win.show_labels', ['F9'])
 
-		self.add_action_simple('fullscreen', self.action_fullscreen, ['F11'])
+		self.add_action_boolean('hide_controls', False, self.action_hide_controls)
+		self.app.set_accels_for_action('win.hide_controls', ['F8'])
+		self.lookup_action('hide_controls').set_enabled(False)
+
+		self.add_action_boolean('fullscreen', False, self.action_fullscreen)
+		self.app.set_accels_for_action('win.fullscreen', ['F11'])
 
 		self.add_action_simple('reload_file', self.action_reload, ['<Ctrl>r'])
 		self.add_action_simple('properties', self.action_properties, None)
-		self.add_action_simple('unfullscreen', self.action_unfullscreen, ['Escape'])
+		self.add_action_simple('unfullscreen', self.action_unfullscreen, None)
 
 		self.add_action_simple('go_up', self.action_go_up, ['<Ctrl>Up'])
 		self.add_action_simple('go_down', self.action_go_down, ['<Ctrl>Down'])
@@ -523,13 +551,13 @@ class DrWindow(Gtk.ApplicationWindow):
 		self.add_action_simple('secondary_color', self.action_color2, ['<Ctrl><Shift>r'])
 		self.add_action_simple('exchange_color', self.exchange_colors, ['<Ctrl>e'])
 
-		editor = self._settings.get_boolean('direct-color-edit')
+		editor = self.gsettings.get_boolean('direct-color-edit')
 		self.app.add_action_boolean('use_editor', editor, self.action_use_editor)
 
 		self.add_action_simple('size_more', self.action_size_more, ['<Ctrl><Shift>Up'])
 		self.add_action_simple('size_less', self.action_size_less, ['<Ctrl><Shift>Down'])
 
-		if self._settings.get_boolean('devel-only'):
+		if self.gsettings.get_boolean('devel-only'):
 			self.add_action_simple('restore_pixbuf', self.action_restore, None)
 			self.add_action_simple('rebuild_from_histo', self.action_rebuild, None)
 			self.add_action_simple('get_values', self.action_getvalues, ['<Ctrl>g'])
@@ -594,7 +622,7 @@ class DrWindow(Gtk.ApplicationWindow):
 			return 'ts'
 		elif 'Cinnamon' in desktop_env:
 			return 'mts'
-		elif 'MATE' in desktop_env or 'XFCE' in desktop_env:
+		elif desktop_env in ['MATE', 'XFCE', 'LXDE', 'LXQt']:
 			return 'mtc'
 		else:
 			return 'hg' # Use the GNOME layout if the desktop is unknown,
@@ -613,7 +641,7 @@ class DrWindow(Gtk.ApplicationWindow):
 		self.placeholder_model = builder.get_object('tool-placeholder')
 
 		# Remember the setting, so no need to restart this at each dialog.
-		self.deco_layout = self._settings.get_string('deco-type')
+		self.deco_layout = self.gsettings.get_string('deco-type')
 		if self.deco_layout == '':
 			self.deco_layout = self.get_auto_decorations()
 
@@ -628,37 +656,14 @@ class DrWindow(Gtk.ApplicationWindow):
 			menubar = 'm' in self.deco_layout
 			self._decorations = DrDecoManagerToolbar(symbolic, menubar, self)
 		else:
-			self._settings.set_string('deco-type', '')
+			self.gsettings.set_string('deco-type', '')
 			self.set_ui_bars() # yes, recursion.
 
 		if self.app.is_beta():
 			self.get_style_context().add_class('devel')
-		self.set_fullscreen_menu()
-
-	def set_fullscreen_menu(self):
-		builder = Gtk.Builder.new_from_resource(UI_PATH + 'win-menus.ui')
-		fullscreen_menu = builder.get_object('fullscreen-menu')
-
-		tabs_list = self._get_menubar_item([[True, 2], [False, 1]])
-		fullscreen_menu.append_section(_("Opened images"), tabs_list)
-
-		classic_tools_section = self._get_menubar_tools_section(1)
-		section = fullscreen_menu.get_item_link(3, Gio.MENU_LINK_SECTION)
-		section.prepend_section(None, classic_tools_section)
-
-		selection_tools_section = self._get_menubar_tools_section(0)
-		transform_tools_section = self._get_menubar_tools_section(2)
-		submenu = section.get_item_link(1, Gio.MENU_LINK_SUBMENU)
-		submenu.append_section(None, selection_tools_section)
-		submenu.append_section(None, transform_tools_section)
-
-		self.fullscreen_btn.set_menu_model(fullscreen_menu)
 
 	def action_main_menu(self, *args):
-		if self.fullscreened:
-			self.fullscreen_btn.set_active(not self.fullscreen_btn.get_active())
-		else:
-			self._decorations.toggle_menu()
+		self._decorations.toggle_menu()
 
 	def action_options_menu(self, *args):
 		"""This displays/hides the tool's options menu, and is implemented as an
@@ -682,6 +687,7 @@ class DrWindow(Gtk.ApplicationWindow):
 			return # there is no active pane nor active image yet
 		self.options_manager.adapt_to_window_size(available_width)
 
+		# Check whether or not the scrollbars should now be displayed
 		self.get_active_image().fake_scrollbar_update()
 
 	def hide_message(self, *args):
@@ -693,7 +699,7 @@ class DrWindow(Gtk.ApplicationWindow):
 		self.info_action.set_visible(False)
 		if show:
 			self.info_label.set_label(label)
-		if show or self._settings.get_boolean('devel-only'):
+		if show or self.gsettings.get_boolean('devel-only') and label != "":
 			print('Drawing: ' + label)
 
 	def prompt_action(self, message, action_name, action_label):
@@ -705,7 +711,8 @@ class DrWindow(Gtk.ApplicationWindow):
 		self.info_action.set_label(action_label)
 
 	def _update_tabs_visibility(self):
-		should_show = (self.notebook.get_n_pages() > 1) and not self.fullscreened
+		controls_hidden = self.lookup_action('hide_controls').get_state()
+		should_show = (self.notebook.get_n_pages() > 1) and not controls_hidden
 		self.notebook.set_show_tabs(should_show)
 
 	############################################################################
@@ -713,22 +720,52 @@ class DrWindow(Gtk.ApplicationWindow):
 
 	def action_unfullscreen(self, *args):
 		"""Simple action, exiting fullscreen."""
-		# TODO connect to signals instead
-		self.unfullscreen()
-		self.set_fullscreen_state(False)
+		fs_action = self.lookup_action('fullscreen')
+		fs_action.change_state(GLib.Variant.new_boolean(False))
 
 	def action_fullscreen(self, *args):
-		# TODO connect to signals instead?
-		self.fullscreen()
-		self.set_fullscreen_state(True)
+		"""Boolean action, toggling fullscreen mode."""
+		# XXX maybe track the window widget's 'window-state-event' to use this
+		# https://lazka.github.io/pgi-docs/Gdk-3.0/flags.html#Gdk.WindowState.FULLSCREEN
+		shall_fullscreen = args[1]
+		if shall_fullscreen:
+			self.fullscreen()
+			self.prompt_message(True, _("Middle-click, tap with 3 fingers, " + \
+			                           "or press F8 to show/hide controls.") + \
+			                           " " + _("Press F11 to exit fullscreen."))
+		else:
+			self.unfullscreen()
+		self._set_controls_hidden(shall_fullscreen)
+		self.lookup_action('hide_controls').set_enabled(shall_fullscreen)
+		self.unfullscreen_btn.set_visible(shall_fullscreen)
+		args[0].set_state(GLib.Variant.new_boolean(shall_fullscreen))
 
-	def set_fullscreen_state(self, state):
-		self.fullscreened = state
-		self.tools_flowbox.set_visible(not state)
-		self.toolbar_box.set_visible(not state) # XXX not if empty!!
-		self.fullscreen_btn.set_visible(state)
+	def action_hide_controls(self, *args):
+		"""Boolean action controlling the visibility of the UI elements such as
+		the tools list, the bottom pane, the menubar/toolbar if any. This can
+		only (in theory) be used while in fullscreen."""
+		controls_hidden = args[1]
+		self.tools_flowbox.set_visible(not controls_hidden)
+		if 't' in self.deco_layout:
+			self.toolbar_box.set_visible(not controls_hidden)
+		if 'm' in self.deco_layout:
+			self.set_show_menubar(not controls_hidden)
+		self.bottom_meta_box.set_visible(not controls_hidden)
+		args[0].set_state(GLib.Variant.new_boolean(controls_hidden))
 		self._update_tabs_visibility()
 
+	def _set_controls_hidden(self, state):
+		hc_action = self.lookup_action('hide_controls')
+		hc_action.change_state(GLib.Variant.new_boolean(state))
+
+	def on_middle_click(self):
+		is_fullscreened = self.lookup_action('fullscreen').get_state()
+		if is_fullscreened:
+			hc_action = self.lookup_action('hide_controls')
+			self._set_controls_hidden(not hc_action.get_state())
+		else:
+			self.options_manager.get_active_pane().middle_click_action()
+
 	############################################################################
 	# SIDE PANE (TOOLS) ########################################################
 
@@ -759,11 +796,11 @@ class DrWindow(Gtk.ApplicationWindow):
 
 	def on_show_labels_setting_changed(self, *args):
 		# TODO https://lazka.github.io/pgi-docs/Gio-2.0/classes/Settings.html#Gio.Settings.create_action
-		self.set_tools_labels_visibility(self._settings.get_boolean('show-labels'))
+		self.set_tools_labels_visibility(self.gsettings.get_boolean('show-labels'))
 
 	def action_show_labels(self, *args):
 		show_labels = not args[0].get_state()
-		self._settings.set_boolean('show-labels', show_labels)
+		self.gsettings.set_boolean('show-labels', show_labels)
 		args[0].set_state(GLib.Variant.new_boolean(show_labels))
 
 	############################################################################
@@ -797,7 +834,6 @@ class DrWindow(Gtk.ApplicationWindow):
 		self.get_active_image().update()
 		self.active_tool_id = new_tool_id
 		self.active_tool().on_tool_selected()
-		self._update_fullscreen_icon()
 		self._update_bottom_pane()
 		self.get_active_image().update_actions_state()
 		self.set_picture_title()
@@ -822,13 +858,6 @@ class DrWindow(Gtk.ApplicationWindow):
 			    "the tool '%s', please report this bug.") % self.active_tool_id)
 			print(e)
 
-	def _update_fullscreen_icon(self):
-		"""Show the icon of the currently active tool on the button managing
-		fullscreen's main menu."""
-		name = self.active_tool().icon_name
-		img = Gtk.Image.new_from_icon_name(name, Gtk.IconSize.BUTTON)
-		self.fullscreen_btn.set_image(img)
-
 	def active_tool(self):
 		return self.tools[self.active_tool_id]
 
@@ -861,7 +890,7 @@ class DrWindow(Gtk.ApplicationWindow):
 
 	def action_use_editor(self, *args):
 		use_editor = not args[0].get_state()
-		self._settings.set_boolean('direct-color-edit', use_editor)
+		self.gsettings.set_boolean('direct-color-edit', use_editor)
 		args[0].set_state(GLib.Variant.new_boolean(use_editor))
 		self.options_manager.set_palette_setting(use_editor)
 
